import type { CommitResult, SimpleGit } from '../../../typings';
import type { StringTask } from '../types';
export declare function commitTask(message: string[], files: string[], customArgs: string[]): StringTask<CommitResult>;
export default function (): Pick<SimpleGit, 'commit'>;
