import type { SimpleGit } from '../../../typings';
export interface VersionResult {
    major: number;
    minor: number;
    patch: number | string;
    agent: string;
    installed: boolean;
}
export default function (): Pick<SimpleGit, 'version'>;
